Documentation
¶
Overview ¶
Package png renders asciinema cast files to still PNG images.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrValidation = errors.New("png validation failed")
ErrValidation indicates that a rendered PNG failed validation.
Functions ¶
Types ¶
type FrameSelection ¶
type FrameSelection struct {
// contains filtered or unexported fields
}
FrameSelection identifies which frame to snapshot from a rendered GIF.
func ParseFrameSelection ¶
func ParseFrameSelection(value string) (FrameSelection, error)
ParseFrameSelection parses snapshot frame syntax: last, <index>, at:<ms>.
type Renderer ¶
type Renderer struct {
Frame FrameSelection
}
Renderer renders a cast into a PNG snapshot.
type Validation ¶
Validation describes a decoded PNG.
func Validate ¶
func Validate(path string) (Validation, error)
Validate decodes a PNG and verifies it has visible image content.
Click to show internal directories.
Click to hide internal directories.